<?php

/* Copyright (C) 2005-2014 Laurent Destailleur	<eldy@users.sourceforge.net>
 * Copyright (C) 2005-2014 Regis Houssin		<regis.houssin@capnetworks.com>
 * Copyright (C) 2014      Marcos García		<marcosgdf@gmail.com>
 * Copyright (C) 2015      Bahfir Abbes        <bafbes@gmail.com>
 * Copyright (C) 2017      Nicolas ZABOURI        <info@inovea-conseil.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *  \file       htdocs/core/triggers/interface_90_all_Demo.class.php
 *  \ingroup    core
 *  \brief      Fichier de demo de personalisation des actions du workflow
 *  \remarks    Son propre fichier d'actions peut etre cree par recopie de celui-ci:
 *              - Le nom du fichier doit etre: interface_99_modMymodule_Mytrigger.class.php
 * 				                           ou: interface_99_all_Mytrigger.class.php
 *              - Le fichier doit rester stocke dans core/triggers
 *              - Le nom de la classe doit etre InterfaceMytrigger
 *              - Le nom de la propriete name doit etre Mytrigger
 */
require_once DOL_DOCUMENT_ROOT . '/core/triggers/dolibarrtriggers.class.php';

/**
 *  Class of triggers for demo module
 */
class InterfaceProductSupplierPrice extends DolibarrTriggers {

    public $family = 'other';
    public $picto = 'technic';
    public $description = "Triggers of this module are empty functions. They have no effect. They are provided for tutorial purpose only.";
    public $version = self::VERSION_DOLIBARR;

    /**
     * Function called when a Dolibarrr business event is done.
     * All functions "runTrigger" are triggered if file is inside directory htdocs/core/triggers or htdocs/module/code/triggers (and declared)
     *
     * @param string		$action		Event action code
     * @param Object		$object     Object concerned. Some context information may also be provided into array property object->context.
     * @param User		    $user       Object user
     * @param Translate 	$langs      Object langs
     * @param conf		    $conf       Object conf
     * @return int         				<0 if KO, 0 if no triggered ran, >0 if OK
     */
    public function runTrigger($action, $object, User $user, Translate $langs, Conf $conf) {
        global $db, $conf;

        switch ($action) {
        
            case 'ORDER_SUPPLIER_VALIDATE':
                $port = $object->array_options['options_Transport'];
                if(!empty($port)){
                $totalht = $object->total_ht;
                
		if ($totalht == 0) {
                    foreach($object->lines as $l){
                        $totalht += $l->total_ht;
                    }
                }
                
                $prorata = floatval($port) / $totalht;
                
                foreach($object->lines as $l){
                    $l->subprice += $l->subprice*$prorata;
                    $l->subprice = round($l->subprice,2);
                    $l->total_ht = ($l->subprice - ($l->subprice * $l->remise_percent/100)) * $l->qty;
                    $l->total_tva = ($l->total_ht * $l->tva_tx)/100;
                    $l->total_ttc = $l->total_ht + $l->total_tva;
                    
                    $l->multicurrency_subprice = $l->subprice;
                    $l->multicurrency_total_ht = $l->total_ht;
                    $l->multicurrency_total_tva = $l->total_tva;
                    $l->multicurrency_total_ttc = $l->total_ttc;
                    
                    $l->update(1);


                }
                $object->update_price(1);
                }
            break;
        }

        return 0;
    }

}
